@@ -39,14 +39,14 @@ class CurlFactoryTest extends TestCase
                 'Foo' => 'Bar',
                 'Baz' => 'bam',
                 'Content-Length' => 2,
-            ], 'hi')
+            ], 'hi'),
         ]);
         $stream = Psr7\Utils::streamFor();
         $request = new Psr7\Request('PUT', Server::$url, [
-            'Hi'             => ' 123',
-            'Content-Length' => '7'
+            'Hi' => ' 123',
+            'Content-Length' => '7',
         ], 'testing');
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $result = $f->create($request, ['sink' => $stream]);
         self::assertInstanceOf(EasyHandle::class, $result);
         if (\PHP_VERSION_ID >= 80000) {
@@ -66,7 +66,7 @@ class CurlFactoryTest extends TestCase
         self::assertSame('testing', $_SERVER['_curl'][\CURLOPT_POSTFIELDS]);
         self::assertEquals(0, $_SERVER['_curl'][\CURLOPT_RETURNTRANSFER]);
         self::assertEquals(0, $_SERVER['_curl'][\CURLOPT_HEADER]);
-        self::assertSame(150, $_SERVER['_curl'][\CURLOPT_CONNECTTIMEOUT]);
+        self::assertSame(300, $_SERVER['_curl'][\CURLOPT_CONNECTTIMEOUT]);
         self::assertInstanceOf('Closure', $_SERVER['_curl'][\CURLOPT_HEADERFUNCTION]);
         if (\defined('CURLOPT_PROTOCOLS')) {
             self::assertSame(
@@ -118,7 +118,7 @@ class CurlFactoryTest extends TestCase
 
     public function testValidatesVerify()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
 
         $this->expectException(\InvalidArgumentException::class);
         $this->expectExceptionMessage('SSL CA bundle not found: /does/not/exist');
@@ -127,7 +127,7 @@ class CurlFactoryTest extends TestCase
 
     public function testCanSetVerifyToFile()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', 'http://foo.com'), ['verify' => __FILE__]);
         self::assertEquals(__FILE__, $_SERVER['_curl'][\CURLOPT_CAINFO]);
         self::assertEquals(2, $_SERVER['_curl'][\CURLOPT_SSL_VERIFYHOST]);
@@ -136,7 +136,7 @@ class CurlFactoryTest extends TestCase
 
     public function testCanSetVerifyToDir()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', 'http://foo.com'), ['verify' => __DIR__]);
         self::assertEquals(__DIR__, $_SERVER['_curl'][\CURLOPT_CAPATH]);
         self::assertEquals(2, $_SERVER['_curl'][\CURLOPT_SSL_VERIFYHOST]);
@@ -145,7 +145,7 @@ class CurlFactoryTest extends TestCase
 
     public function testAddsVerifyAsTrue()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', Server::$url), ['verify' => true]);
         self::assertEquals(2, $_SERVER['_curl'][\CURLOPT_SSL_VERIFYHOST]);
         self::assertTrue($_SERVER['_curl'][\CURLOPT_SSL_VERIFYPEER]);
@@ -154,7 +154,7 @@ class CurlFactoryTest extends TestCase
 
     public function testCanDisableVerify()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', Server::$url), ['verify' => false]);
         self::assertEquals(0, $_SERVER['_curl'][\CURLOPT_SSL_VERIFYHOST]);
         self::assertFalse($_SERVER['_curl'][\CURLOPT_SSL_VERIFYPEER]);
@@ -162,14 +162,14 @@ class CurlFactoryTest extends TestCase
 
     public function testAddsProxy()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', Server::$url), ['proxy' => 'http://bar.com']);
         self::assertEquals('http://bar.com', $_SERVER['_curl'][\CURLOPT_PROXY]);
     }
 
     public function testAddsViaScheme()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', Server::$url), [
             'proxy' => ['http' => 'http://bar.com', 'https' => 'https://t'],
         ]);
@@ -183,12 +183,12 @@ class CurlFactoryTest extends TestCase
 
     private function checkNoProxyForHost($url, $noProxy, $assertUseProxy)
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', $url), [
             'proxy' => [
                 'http' => 'http://bar.com',
                 'https' => 'https://t',
-                'no' => $noProxy
+                'no' => $noProxy,
             ],
         ]);
         if ($assertUseProxy) {
@@ -206,13 +206,13 @@ class CurlFactoryTest extends TestCase
                 'Foo' => 'Bar',
                 'Baz' => 'bam',
                 'Content-Length' => 2,
-            ], 'hi')
+            ], 'hi'),
         ]);
 
         $handler = new Handler\CurlMultiHandler();
         $request = new Psr7\Request('GET', 'http://www.example.com', [], null, '1.0');
         $promise = $handler($request, [
-            'proxy' => Server::$url
+            'proxy' => Server::$url,
         ]);
         $response = $promise->wait();
         self::assertSame(200, $response->getStatusCode());
@@ -221,9 +221,49 @@ class CurlFactoryTest extends TestCase
         self::assertSame('hi', (string) $response->getBody());
     }
 
+    public function testValidatesCryptoMethodInvalidMethod()
+    {
+        $f = new CurlFactory(3);
+
+        $this->expectException(\InvalidArgumentException::class);
+        $this->expectExceptionMessage('Invalid crypto_method request option: unknown version provided');
+        $f->create(new Psr7\Request('GET', Server::$url), ['crypto_method' => 123]);
+    }
+
+    public function testAddsCryptoMethodTls10()
+    {
+        $f = new CurlFactory(3);
+        $f->create(new Psr7\Request('GET', Server::$url), ['crypto_method' => \STREAM_CRYPTO_METHOD_TLSv1_0_CLIENT]);
+        self::assertEquals(\CURL_SSLVERSION_TLSv1_0, $_SERVER['_curl'][\CURLOPT_SSLVERSION]);
+    }
+
+    public function testAddsCryptoMethodTls11()
+    {
+        $f = new CurlFactory(3);
+        $f->create(new Psr7\Request('GET', Server::$url), ['crypto_method' => \STREAM_CRYPTO_METHOD_TLSv1_1_CLIENT]);
+        self::assertEquals(\CURL_SSLVERSION_TLSv1_1, $_SERVER['_curl'][\CURLOPT_SSLVERSION]);
+    }
+
+    public function testAddsCryptoMethodTls12()
+    {
+        $f = new CurlFactory(3);
+        $f->create(new Psr7\Request('GET', Server::$url), ['crypto_method' => \STREAM_CRYPTO_METHOD_TLSv1_2_CLIENT]);
+        self::assertEquals(\CURL_SSLVERSION_TLSv1_2, $_SERVER['_curl'][\CURLOPT_SSLVERSION]);
+    }
+
+    /**
+     * @requires PHP >= 7.4
+     */
+    public function testAddsCryptoMethodTls13()
+    {
+        $f = new CurlFactory(3);
+        $f->create(new Psr7\Request('GET', Server::$url), ['crypto_method' => \STREAM_CRYPTO_METHOD_TLSv1_3_CLIENT]);
+        self::assertEquals(\CURL_SSLVERSION_TLSv1_3, $_SERVER['_curl'][\CURLOPT_SSLVERSION]);
+    }
+
     public function testValidatesSslKey()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
 
         $this->expectException(\InvalidArgumentException::class);
         $this->expectExceptionMessage('SSL private key not found: /does/not/exist');
@@ -232,14 +272,14 @@ class CurlFactoryTest extends TestCase
 
     public function testAddsSslKey()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', Server::$url), ['ssl_key' => __FILE__]);
         self::assertEquals(__FILE__, $_SERVER['_curl'][\CURLOPT_SSLKEY]);
     }
 
     public function testAddsSslKeyWithPassword()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', Server::$url), ['ssl_key' => [__FILE__, 'test']]);
         self::assertEquals(__FILE__, $_SERVER['_curl'][\CURLOPT_SSLKEY]);
         self::assertEquals('test', $_SERVER['_curl'][\CURLOPT_SSLKEYPASSWD]);
@@ -247,7 +287,7 @@ class CurlFactoryTest extends TestCase
 
     public function testAddsSslKeyWhenUsingArraySyntaxButNoPassword()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', Server::$url), ['ssl_key' => [__FILE__]]);
 
         self::assertEquals(__FILE__, $_SERVER['_curl'][\CURLOPT_SSLKEY]);
@@ -255,7 +295,7 @@ class CurlFactoryTest extends TestCase
 
     public function testValidatesCert()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
 
         $this->expectException(\InvalidArgumentException::class);
         $this->expectExceptionMessage('SSL certificate not found: /does/not/exist');
@@ -264,14 +304,14 @@ class CurlFactoryTest extends TestCase
 
     public function testAddsCert()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', Server::$url), ['cert' => __FILE__]);
         self::assertEquals(__FILE__, $_SERVER['_curl'][\CURLOPT_SSLCERT]);
     }
 
     public function testAddsCertWithPassword()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', Server::$url), ['cert' => [__FILE__, 'test']]);
         self::assertEquals(__FILE__, $_SERVER['_curl'][\CURLOPT_SSLCERT]);
         self::assertEquals('test', $_SERVER['_curl'][\CURLOPT_SSLCERTPASSWD]);
@@ -279,10 +319,10 @@ class CurlFactoryTest extends TestCase
 
     public function testAddsDerCert()
     {
-        $certFile = tempnam(sys_get_temp_dir(), "mock_test_cert");
+        $certFile = tempnam(sys_get_temp_dir(), 'mock_test_cert');
         rename($certFile, $certFile .= '.der');
         try {
-            $f = new Handler\CurlFactory(3);
+            $f = new CurlFactory(3);
             $f->create(new Psr7\Request('GET', Server::$url), ['cert' => $certFile]);
             self::assertArrayHasKey(\CURLOPT_SSLCERTTYPE, $_SERVER['_curl']);
             self::assertEquals('DER', $_SERVER['_curl'][\CURLOPT_SSLCERTTYPE]);
@@ -293,10 +333,10 @@ class CurlFactoryTest extends TestCase
 
     public function testAddsP12Cert()
     {
-        $certFile = tempnam(sys_get_temp_dir(), "mock_test_cert");
+        $certFile = tempnam(sys_get_temp_dir(), 'mock_test_cert');
         rename($certFile, $certFile .= '.p12');
         try {
-            $f = new Handler\CurlFactory(3);
+            $f = new CurlFactory(3);
             $f->create(new Psr7\Request('GET', Server::$url), ['cert' => $certFile]);
             self::assertArrayHasKey(\CURLOPT_SSLCERTTYPE, $_SERVER['_curl']);
             self::assertEquals('P12', $_SERVER['_curl'][\CURLOPT_SSLCERTTYPE]);
@@ -307,7 +347,7 @@ class CurlFactoryTest extends TestCase
 
     public function testValidatesProgress()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
 
         $this->expectException(\InvalidArgumentException::class);
         $this->expectExceptionMessage('progress client option must be callable');
@@ -324,8 +364,8 @@ class CurlFactoryTest extends TestCase
         $response->wait();
         \rewind($res);
         $output = \str_replace("\r", '', \stream_get_contents($res));
-        self::assertStringContainsString("> HEAD / HTTP/1.1", $output);
-        self::assertStringContainsString("< HTTP/1.1 200", $output);
+        self::assertStringContainsString('> HEAD / HTTP/1.1', $output);
+        self::assertStringContainsString('< HTTP/1.1 200', $output);
         \fclose($res);
     }
 
@@ -358,6 +398,7 @@ class CurlFactoryTest extends TestCase
         $response = new Psr7\Response(200, $headers, $content);
         Server::flush();
         Server::enqueue([$response]);
+
         return $content;
     }
 
@@ -404,8 +445,8 @@ class CurlFactoryTest extends TestCase
         self::assertEquals('test', (string) $response->getBody());
         self::assertFalse($response->hasHeader('content-encoding'));
         self::assertTrue(
-            !$response->hasHeader('content-length') ||
-            $response->getHeaderLine('content-length') == $response->getBody()->getSize()
+            !$response->hasHeader('content-length')
+            || $response->getHeaderLine('content-length') == $response->getBody()->getSize()
         );
     }
 
@@ -425,8 +466,8 @@ class CurlFactoryTest extends TestCase
 
         // Verify that the content-length matches the encoded size.
         self::assertTrue(
-            !$response->hasHeader('content-length') ||
-            $response->getHeaderLine('content-length') == \strlen(\gzencode('test'))
+            !$response->hasHeader('content-length')
+            || $response->getHeaderLine('content-length') == \strlen(\gzencode('test'))
         );
     }
 
@@ -460,7 +501,7 @@ class CurlFactoryTest extends TestCase
         $request = new Psr7\Request('GET', Server::$url);
         $response = $handler($request, [
             'decode_content' => true,
-            'sink'           => $stream,
+            'sink' => $stream,
         ]);
         $response->wait();
         \rewind($stream);
@@ -475,7 +516,7 @@ class CurlFactoryTest extends TestCase
         $request = new Psr7\Request('GET', Server::$url);
         $response = $handler($request, [
             'decode_content' => true,
-            'sink'           => $stream,
+            'sink' => $stream,
         ]);
         $response->wait();
         self::assertEquals('test', (string) $stream);
@@ -489,7 +530,7 @@ class CurlFactoryTest extends TestCase
         $request = new Psr7\Request('GET', Server::$url);
         $response = $handler($request, [
             'decode_content' => true,
-            'sink'           => $tmpfile,
+            'sink' => $tmpfile,
         ]);
         $response->wait();
         self::assertStringEqualsFile($tmpfile, 'test');
@@ -525,14 +566,15 @@ class CurlFactoryTest extends TestCase
 
     public function testFailsWhenCannotRewindRetryAfterNoResponse()
     {
-        $factory = new Handler\CurlFactory(1);
+        $factory = new CurlFactory(1);
         $stream = Psr7\Utils::streamFor('abc');
         $stream->read(1);
         $stream = new Psr7\NoSeekStream($stream);
         $request = new Psr7\Request('PUT', Server::$url, [], $stream);
         $fn = static function ($request, $options) use (&$fn, $factory) {
             $easy = $factory->create($request, $options);
-            return Handler\CurlFactory::finish($fn, $easy, $factory);
+
+            return CurlFactory::finish($fn, $easy, $factory);
         };
 
         $this->expectException(RequestException::class);
@@ -546,22 +588,23 @@ class CurlFactoryTest extends TestCase
 
         $fn = static function ($r, $options) use (&$callHandler) {
             $callHandler = true;
+
             return P\Create::promiseFor(new Psr7\Response());
         };
 
         $bd = Psr7\FnStream::decorate(Psr7\Utils::streamFor('test'), [
-            'tell'   => static function () {
+            'tell' => static function () {
                 return 1;
             },
             'rewind' => static function () use (&$called) {
                 $called = true;
-            }
+            },
         ]);
 
-        $factory = new Handler\CurlFactory(1);
+        $factory = new CurlFactory(1);
         $req = new Psr7\Request('PUT', Server::$url, [], $bd);
         $easy = $factory->create($req, []);
-        $res = Handler\CurlFactory::finish($fn, $easy, $factory);
+        $res = CurlFactory::finish($fn, $easy, $factory);
         $res = $res->wait();
         self::assertTrue($callHandler);
         self::assertTrue($called);
@@ -570,12 +613,13 @@ class CurlFactoryTest extends TestCase
 
     public function testFailsWhenRetryMoreThanThreeTimes()
     {
-        $factory = new Handler\CurlFactory(1);
+        $factory = new CurlFactory(1);
         $call = 0;
         $fn = static function ($request, $options) use (&$mock, &$call, $factory) {
-            $call++;
+            ++$call;
             $easy = $factory->create($request, $options);
-            return Handler\CurlFactory::finish($mock, $easy, $factory);
+
+            return CurlFactory::finish($mock, $easy, $factory);
         };
         $mock = new Handler\MockHandler([$fn, $fn, $fn]);
         $p = $mock(new Psr7\Request('PUT', Server::$url, [], 'test'), []);
@@ -594,7 +638,7 @@ class CurlFactoryTest extends TestCase
             new Psr7\Response(200, ['Test' => 'Hello', 'Content-Length' => 4], 'test'),
         ]);
         $request = new Psr7\Request('PUT', Server::$url, [
-            'Expect' => '100-Continue'
+            'Expect' => '100-Continue',
         ], 'test');
         $handler = new Handler\CurlMultiHandler();
         $response = $handler($request, [])->wait();
@@ -609,7 +653,7 @@ class CurlFactoryTest extends TestCase
     {
         $m = new \ReflectionMethod(CurlFactory::class, 'finishError');
         $m->setAccessible(true);
-        $factory = new Handler\CurlFactory(1);
+        $factory = new CurlFactory(1);
         $easy = $factory->create(new Psr7\Request('GET', Server::$url), []);
         $easy->errno = \CURLE_COULDNT_CONNECT;
         $response = $m->invoke(
@@ -626,10 +670,10 @@ class CurlFactoryTest extends TestCase
 
     public function testAddsTimeouts()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $f->create(new Psr7\Request('GET', Server::$url), [
-            'timeout'         => 0.1,
-            'connect_timeout' => 0.2
+            'timeout' => 0.1,
+            'connect_timeout' => 0.2,
         ]);
         self::assertEquals(100, $_SERVER['_curl'][\CURLOPT_TIMEOUT_MS]);
         self::assertEquals(200, $_SERVER['_curl'][\CURLOPT_CONNECTTIMEOUT_MS]);
@@ -637,11 +681,11 @@ class CurlFactoryTest extends TestCase
 
     public function testAddsStreamingBody()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $bd = Psr7\FnStream::decorate(Psr7\Utils::streamFor('foo'), [
             'getSize' => static function () {
                 return null;
-            }
+            },
         ]);
         $request = new Psr7\Request('PUT', Server::$url, [], $bd);
         $f->create($request, []);
@@ -651,18 +695,18 @@ class CurlFactoryTest extends TestCase
 
     public function testEnsuresDirExistsBeforeThrowingWarning()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
 
         $this->expectException(\RuntimeException::class);
         $this->expectExceptionMessage('Directory /does/not/exist/so does not exist for sink value of /does/not/exist/so/error.txt');
         $f->create(new Psr7\Request('GET', Server::$url), [
-            'sink' => '/does/not/exist/so/error.txt'
+            'sink' => '/does/not/exist/so/error.txt',
         ]);
     }
 
     public function testClosesIdleHandles()
     {
-        $f = new Handler\CurlFactory(3);
+        $f = new CurlFactory(3);
         $req = new Psr7\Request('GET', Server::$url);
         $easy = $f->create($req, []);
         $h1 = $easy->handle;
@@ -686,13 +730,13 @@ class CurlFactoryTest extends TestCase
     public function testRejectsPromiseWhenCreateResponseFails()
     {
         Server::flush();
-        Server::enqueueRaw(999, "Incorrect", ['X-Foo' => 'bar'], 'abc 123');
+        Server::enqueueRaw(999, 'Incorrect', ['X-Foo' => 'bar'], 'abc 123');
 
         $req = new Psr7\Request('GET', Server::$url);
         $handler = new Handler\CurlHandler();
         $promise = $handler($req, []);
 
-        $this->expectException(\GuzzleHttp\Exception\RequestException::class);
+        $this->expectException(RequestException::class);
         $this->expectExceptionMessage('An error was encountered while creating the response');
         $promise->wait();
     }
@@ -710,14 +754,14 @@ class CurlFactoryTest extends TestCase
     {
         Server::flush();
         Server::enqueue([
-            new Psr7\Response(200, ['X-Foo' => 'bar'], 'abc 123')
+            new Psr7\Response(200, ['X-Foo' => 'bar'], 'abc 123'),
         ]);
         $req = new Psr7\Request('GET', Server::$url);
         $handler = new Handler\CurlHandler();
         $promise = $handler($req, [
             'on_headers' => static function () {
                 throw new \Exception('test');
-            }
+            },
         ]);
 
         $this->expectException(RequestException::class);
@@ -729,7 +773,7 @@ class CurlFactoryTest extends TestCase
     {
         Server::flush();
         Server::enqueue([
-            new Psr7\Response(200, ['X-Foo' => 'bar'], 'abc 123')
+            new Psr7\Response(200, ['X-Foo' => 'bar'], 'abc 123'),
         ]);
         $req = new Psr7\Request('GET', Server::$url);
         $got = null;
@@ -738,17 +782,18 @@ class CurlFactoryTest extends TestCase
         $stream = Psr7\FnStream::decorate($stream, [
             'write' => static function ($data) use ($stream, &$got) {
                 self::assertNotNull($got);
+
                 return $stream->write($data);
-            }
+            },
         ]);
 
         $handler = new Handler\CurlHandler();
         $promise = $handler($req, [
-            'sink'       => $stream,
+            'sink' => $stream,
             'on_headers' => static function (ResponseInterface $res) use (&$got) {
                 $got = $res;
                 self::assertEquals('bar', $res->getHeaderLine('X-Foo'));
-            }
+            },
         ]);
 
         $response = $promise->wait();
@@ -767,7 +812,7 @@ class CurlFactoryTest extends TestCase
         $promise = $handler($req, [
             'on_stats' => static function (TransferStats $stats) use (&$gotStats) {
                 $gotStats = $stats;
-            }
+            },
         ]);
         $response = $promise->wait();
         self::assertSame(200, $response->getStatusCode());
@@ -794,7 +839,7 @@ class CurlFactoryTest extends TestCase
             'timeout' => 0.001,
             'on_stats' => static function (TransferStats $stats) use (&$gotStats) {
                 $gotStats = $stats;
-            }
+            },
         ]);
         $promise->wait(false);
         self::assertFalse($gotStats->hasResponse());
@@ -862,7 +907,7 @@ class CurlFactoryTest extends TestCase
         Server::enqueue([
             new Psr7\Response(200, [
                 'Content-Length' => $expectedLength,
-            ], \str_repeat('x', $expectedLength))
+            ], \str_repeat('x', $expectedLength)),
         ]);
 
         $handler = new Handler\CurlMultiHandler();
@@ -886,7 +931,7 @@ class CurlFactoryTest extends TestCase
         $this->expectException(RequestException::class);
         $this->expectExceptionMessage('cURL error 1: Received HTTP/0.9 when not allowed');
 
-        $a(new Psr7\Request('GET', Server::$url . 'guzzle-server/garbage'), [])->wait();
+        $a(new Psr7\Request('GET', Server::$url.'guzzle-server/garbage'), [])->wait();
     }
 
     public function testHandlesInvalidStatusCodeGracefully()
@@ -896,6 +941,6 @@ class CurlFactoryTest extends TestCase
         $this->expectException(RequestException::class);
         $this->expectExceptionMessage('An error was encountered while creating the response');
 
-        $a(new Psr7\Request('GET', Server::$url . 'guzzle-server/bad-status'), [])->wait();
+        $a(new Psr7\Request('GET', Server::$url.'guzzle-server/bad-status'), [])->wait();
     }
 }
