@@ -28,7 +28,7 @@ class StreamHandlerTest extends TestCase
             new Response(200, [
                 'Foo' => 'Bar',
                 'Content-Length' => 8,
-            ], 'hi there')
+            ], 'hi there'),
         ]);
     }
 
@@ -69,7 +69,7 @@ class StreamHandlerTest extends TestCase
         $handler = new StreamHandler();
         $request = new Request(
             'PUT',
-            Server::$url . 'foo?baz=bar',
+            Server::$url.'foo?baz=bar',
             ['Foo' => 'Bar'],
             'test'
         );
@@ -153,7 +153,7 @@ class StreamHandlerTest extends TestCase
             new Response(200, [
                 'Foo' => 'Bar',
                 'Content-Length' => 8,
-            ], 'hi there... This has way too much data!')
+            ], 'hi there... This has way too much data!'),
         ]);
         $handler = new StreamHandler();
         $request = new Request('GET', Server::$url);
@@ -172,7 +172,7 @@ class StreamHandlerTest extends TestCase
             new Response(200, [
                 'Foo' => 'Bar',
                 'Content-Length' => 8,
-            ], '')
+            ], ''),
         ]);
         $handler = new StreamHandler();
         $request = new Request('HEAD', Server::$url);
@@ -190,8 +190,8 @@ class StreamHandlerTest extends TestCase
         Server::enqueue([
             new Response(200, [
                 'Content-Encoding' => 'gzip',
-                'Content-Length'   => \strlen($content),
-            ], $content)
+                'Content-Length' => \strlen($content),
+            ], $content),
         ]);
         $handler = new StreamHandler();
         $request = new Request('GET', Server::$url);
@@ -208,8 +208,8 @@ class StreamHandlerTest extends TestCase
         Server::enqueue([
             new Response(200, [
                 'Content-Encoding' => 'gzip',
-                'Content-Length'   => \strlen($content),
-            ], $content)
+                'Content-Length' => \strlen($content),
+            ], $content),
         ]);
         $handler = new StreamHandler();
         $request = new Request('HEAD', Server::$url);
@@ -226,8 +226,8 @@ class StreamHandlerTest extends TestCase
         Server::enqueue([
             new Response(200, [
                 'Content-Encoding' => 'gzip',
-                'Content-Length'   => \strlen($content),
-            ], $content)
+                'Content-Length' => \strlen($content),
+            ], $content),
         ]);
         $handler = new StreamHandler();
         $request = new Request('GET', Server::$url);
@@ -250,8 +250,8 @@ class StreamHandlerTest extends TestCase
         Server::enqueue([
             new Response(200, [
                 'Content-Encoding' => 'gzip',
-                'Content-Length'   => \strlen($content),
-            ], $content)
+                'Content-Length' => \strlen($content),
+            ], $content),
         ]);
         $handler = new StreamHandler();
         $request = new Request('GET', Server::$url);
@@ -276,6 +276,7 @@ class StreamHandlerTest extends TestCase
         $handler = new StreamHandler();
         $opts['stream'] = true;
         $request = new Request('GET', Server::$url);
+
         return $handler($request, $opts)->wait();
     }
 
@@ -303,7 +304,7 @@ class StreamHandlerTest extends TestCase
         $url = Server::$url;
         $res = $this->getSendResult(['proxy' => [
             'http' => $url,
-            'no'   => ['*']
+            'no' => ['*'],
         ]]);
         $opts = \stream_context_get_options($res->getBody()->detach());
         self::assertArrayNotHasKey('proxy', $opts['http']);
@@ -315,7 +316,7 @@ class StreamHandlerTest extends TestCase
         $handler = new StreamHandler();
         $request = new Request('GET', 'http://www.example.com', [], null, '1.0');
         $response = $handler($request, [
-            'proxy' => Server::$url
+            'proxy' => Server::$url,
         ])->wait();
         self::assertSame(200, $response->getStatusCode());
         self::assertSame('OK', $response->getReasonPhrase());
@@ -379,6 +380,45 @@ class StreamHandlerTest extends TestCase
         $this->getSendResult(['verify' => 10]);
     }
 
+    public function testEnsuresCryptoMethodOptionIsValid()
+    {
+        $this->expectException(\InvalidArgumentException::class);
+        $this->expectExceptionMessage('Invalid crypto_method request option: unknown version provided');
+
+        $this->getSendResult(['crypto_method' => 123]);
+    }
+
+    public function testSetsCryptoMethodTls10()
+    {
+        $res = $this->getSendResult(['crypto_method' => \STREAM_CRYPTO_METHOD_TLSv1_0_CLIENT]);
+        $opts = \stream_context_get_options($res->getBody()->detach());
+        self::assertSame(\STREAM_CRYPTO_METHOD_TLSv1_0_CLIENT, $opts['http']['crypto_method']);
+    }
+
+    public function testSetsCryptoMethodTls11()
+    {
+        $res = $this->getSendResult(['crypto_method' => \STREAM_CRYPTO_METHOD_TLSv1_1_CLIENT]);
+        $opts = \stream_context_get_options($res->getBody()->detach());
+        self::assertSame(\STREAM_CRYPTO_METHOD_TLSv1_1_CLIENT, $opts['http']['crypto_method']);
+    }
+
+    public function testSetsCryptoMethodTls12()
+    {
+        $res = $this->getSendResult(['crypto_method' => \STREAM_CRYPTO_METHOD_TLSv1_2_CLIENT]);
+        $opts = \stream_context_get_options($res->getBody()->detach());
+        self::assertSame(\STREAM_CRYPTO_METHOD_TLSv1_2_CLIENT, $opts['http']['crypto_method']);
+    }
+
+    /**
+     * @requires PHP >=7.4
+     */
+    public function testSetsCryptoMethodTls13()
+    {
+        $res = $this->getSendResult(['crypto_method' => \STREAM_CRYPTO_METHOD_TLSv1_3_CLIENT]);
+        $opts = \stream_context_get_options($res->getBody()->detach());
+        self::assertSame(\STREAM_CRYPTO_METHOD_TLSv1_3_CLIENT, $opts['http']['crypto_method']);
+    }
+
     public function testCanSetPasswordWhenSettingCert()
     {
         $path = __FILE__;
@@ -439,7 +479,7 @@ class StreamHandlerTest extends TestCase
         $this->queueRes();
         $buffer = \fopen('php://memory', 'w+');
         $this->getSendResult([
-            'debug'    => $buffer,
+            'debug' => $buffer,
             'progress' => static function (...$args) use (&$called) {
                 $called[] = $args;
             },
@@ -530,7 +570,7 @@ class StreamHandlerTest extends TestCase
 
     public function testDoesSleep()
     {
-        $response = new response(200);
+        $response = new Response(200);
         Server::enqueue([$response]);
         $a = new StreamHandler();
         $request = new Request('GET', Server::$url);
@@ -552,14 +592,14 @@ class StreamHandlerTest extends TestCase
     {
         Server::flush();
         Server::enqueue([
-            new Response(200, ['X-Foo' => 'bar'], 'abc 123')
+            new Response(200, ['X-Foo' => 'bar'], 'abc 123'),
         ]);
         $req = new Request('GET', Server::$url);
         $handler = new StreamHandler();
         $promise = $handler($req, [
             'on_headers' => static function () {
                 throw new \Exception('test');
-            }
+            },
         ]);
 
         $this->expectException(RequestException::class);
@@ -571,7 +611,7 @@ class StreamHandlerTest extends TestCase
     {
         Server::flush();
         Server::enqueue([
-            new Response(200, ['X-Foo' => 'bar'], 'abc 123')
+            new Response(200, ['X-Foo' => 'bar'], 'abc 123'),
         ]);
         $req = new Request('GET', Server::$url);
         $got = null;
@@ -580,17 +620,18 @@ class StreamHandlerTest extends TestCase
         $stream = FnStream::decorate($stream, [
             'write' => static function ($data) use ($stream, &$got) {
                 self::assertNotNull($got);
+
                 return $stream->write($data);
-            }
+            },
         ]);
 
         $handler = new StreamHandler();
         $promise = $handler($req, [
-            'sink'       => $stream,
+            'sink' => $stream,
             'on_headers' => static function (ResponseInterface $res) use (&$got) {
                 $got = $res;
                 self::assertSame('bar', $res->getHeaderLine('X-Foo'));
-            }
+            },
         ]);
 
         $response = $promise->wait();
@@ -602,14 +643,14 @@ class StreamHandlerTest extends TestCase
     public function testInvokesOnStatsOnSuccess()
     {
         Server::flush();
-        Server::enqueue([new Psr7\Response(200)]);
-        $req = new Psr7\Request('GET', Server::$url);
+        Server::enqueue([new Response(200)]);
+        $req = new Request('GET', Server::$url);
         $gotStats = null;
         $handler = new StreamHandler();
         $promise = $handler($req, [
             'on_stats' => static function (TransferStats $stats) use (&$gotStats) {
                 $gotStats = $stats;
-            }
+            },
         ]);
         $response = $promise->wait();
         self::assertSame(200, $response->getStatusCode());
@@ -627,7 +668,7 @@ class StreamHandlerTest extends TestCase
 
     public function testInvokesOnStatsOnError()
     {
-        $req = new Psr7\Request('GET', 'http://127.0.0.1:123');
+        $req = new Request('GET', 'http://127.0.0.1:123');
         $gotStats = null;
         $handler = new StreamHandler();
         $promise = $handler($req, [
@@ -635,7 +676,7 @@ class StreamHandlerTest extends TestCase
             'timeout' => 0.001,
             'on_stats' => static function (TransferStats $stats) use (&$gotStats) {
                 $gotStats = $stats;
-            }
+            },
         ]);
         $promise->wait(false);
         self::assertFalse($gotStats->hasResponse());
@@ -657,13 +698,13 @@ class StreamHandlerTest extends TestCase
     public function testStreamIgnoresZeroTimeout()
     {
         Server::flush();
-        Server::enqueue([new Psr7\Response(200)]);
-        $req = new Psr7\Request('GET', Server::$url);
+        Server::enqueue([new Response(200)]);
+        $req = new Request('GET', Server::$url);
         $gotStats = null;
         $handler = new StreamHandler();
         $promise = $handler($req, [
             'connect_timeout' => 10,
-            'timeout' => 0
+            'timeout' => 0,
         ]);
         $response = $promise->wait();
         self::assertSame(200, $response->getStatusCode());
@@ -676,7 +717,7 @@ class StreamHandlerTest extends TestCase
             new Response(200, [
                 'Foo' => 'Bar',
                 'Content-Length' => '0',
-            ], 'hi there... This has a lot of data!')
+            ], 'hi there... This has a lot of data!'),
         ]);
         $handler = new StreamHandler();
         $request = new Request('GET', Server::$url);
@@ -692,7 +733,7 @@ class StreamHandlerTest extends TestCase
         Server::flush();
         $handler = new StreamHandler();
         $response = $handler(
-            new Request('GET', Server::$url . 'guzzle-server/read-timeout'),
+            new Request('GET', Server::$url.'guzzle-server/read-timeout'),
             [
                 RequestOptions::READ_TIMEOUT => 1,
                 RequestOptions::STREAM => true,
@@ -717,7 +758,7 @@ class StreamHandlerTest extends TestCase
         $this->expectExceptionMessage('An error was encountered while creating the response');
 
         $handler(
-            new Request('GET', Server::$url . 'guzzle-server/garbage'),
+            new Request('GET', Server::$url.'guzzle-server/garbage'),
             [
                 RequestOptions::STREAM => true,
             ]
@@ -732,7 +773,7 @@ class StreamHandlerTest extends TestCase
         $this->expectExceptionMessage('An error was encountered while creating the response');
 
         $handler(
-            new Request('GET', Server::$url . 'guzzle-server/bad-status'),
+            new Request('GET', Server::$url.'guzzle-server/bad-status'),
             [
                 RequestOptions::STREAM => true,
             ]
